@@ -1,9 +1,10 @@
-"""
-Checkout the sources corresponding to the projects a specified egg or enthought
-project depends on.
+# Copyright (c) 2007-2009 by Enthought, Inc.
+# All rights reserved.
+#
+# License: BSD Style.
 
-Copyright (c) 2007-2009 by Enthought, Inc.
-License: BSD Style.
+"""\
+Tools to work with projects, and their dependencies, as a single unit.
 
 """
 
@@ -18,6 +19,7 @@ from enthought.ets.checkout import Checkout
 from enthought.ets.clean import Clean
 from enthought.ets.depends import Depends
 from enthought.ets.develop import Develop
+from enthought.ets.diff import Diff
 from enthought.ets.graph import Graph
 from enthought.ets.info import Info
 from enthought.ets.install import Install
@@ -135,6 +137,7 @@ the subcommands you specify.
     Clean(subparsers)
     Depends(subparsers)
     Develop(subparsers)
+    Diff(subparsers)
     Graph(subparsers)
     Info(subparsers)
     Install(subparsers)
