@@ -40,6 +40,12 @@ class Install(BaseSubcommand):
         # Add options
         self.command_args(parser, 'install')
         self.dry_run(parser)
+        parser.add_argument('-n', '--not-externally-managed',
+            action = 'store_true',
+            help = 'Do not automatically add '
+                '--single-version-externally-managed to the args passed to '
+                'the arguments passed to "setup.py install"',
+            )
         self.setup_args(parser)
 
         # Save the entry point for running this command.
@@ -67,6 +73,9 @@ class Install(BaseSubcommand):
         if len(args.setup_args) > 0:
             command.extend(self.split_command_line_args(args.setup_args))
         command.extend(['install'])
+        if not args.not_externally_managed:
+            command.extend(self.split_command_line_args(
+                '--single-version-externally-managed --record dummy.txt'))
         if len(args.command_args) > 0:
             command.extend(self.split_command_line_args(args.command_args))
         checkouts.perform(command, dry_run=args.dry_run)
