@@ -169,11 +169,11 @@ class ProjectSet(object):
                         try:
 
                             # Add all the install requirements for the project.
-                            for dep in info['install_requires']:
+                            for dep in info.get('install_requires', []):
                                 self.add(dep, parent=name, raise_missing=False)
 
                             # Add all dependencies from the requested extras.
-                            for extra in info['extras']:
+                            for extra in info.get('extras', []):
                                 self._status('Processing "%s" ' % extra + \
                                     'extra for project %s' % name)
                                 self._status_indent += 1
@@ -201,7 +201,7 @@ class ProjectSet(object):
         return
 
 
-    def checkout(self, dir, dry_run=True):
+    def checkout(self, dir, dry_run=True, use_version=False):
         """
         Checkout the source for the known projects to the specified directory.
 
@@ -231,8 +231,11 @@ class ProjectSet(object):
                     ignore_verbose=True)
 
                 if not dry_run:
-                    version = info['version']
-                    target_dir = os.path.join(dir, "%s_%s" % (name, version))
+                    if use_version:
+                        target_dir = os.path.join(dir, "%s_%s" % (name, 
+                            info['version']))
+                    else:
+                        target_dir = os.path.join(dir, name)
                     errcode = subprocess.call(['svn', 'co', url, target_dir])
                     if errcode != 0:
                         break
